@@ -7,7 +7,7 @@ use Class::Utils qw(set_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -163,20 +163,20 @@ Returns instance of class.
 
 =item * C<css>
 
-'CSS::Struct::Output' object for L<process_css> processing.
+'L<CSS::Struct::Output>' object for L</process_css> processing.
 
 Default value is undef.
 
 =item * C<no_css>
 
 No CSS support flag.
-If this flag is set to 1, L<process_css()> returns undef.
+If this flag is set to 1, L</process_css> don't process CSS style.
 
 Default value is 0.
 
 =item * C<tags>
 
-'Tags::Output' object for L<process> processing.
+'L<Tags::Output>' object for L</process> processing.
 
 Default value is undef.
 
@@ -202,7 +202,7 @@ Returns undef.
 
  $obj->process;
 
-Process Tags structure.
+Process L<Tags> structure.
 
 Returns undef.
 
@@ -210,7 +210,7 @@ Returns undef.
 
  $obj->process_css;
 
-Process CSS::Struct structure.
+Process L<CSS::Struct> structure.
 
 Returns undef.
 
@@ -424,12 +424,12 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-© 2021-2022 Michal Josef Špaček
+© 2021-2023 Michal Josef Špaček
 
 BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
